package monnethic.mobile.homepage;

import android.content.Context;
import android.content.Intent;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.example.monnthic.monnethicmobile.R;

import org.json.JSONObject;

import monnethic.mobile.database.User;
import monnethic.mobile.restApi.Config;
import monnethic.mobile.restApi.HttpCallHandler;
import monnethic.mobile.user.UserAccountActivity;

public class RegisterActivity extends AppCompatActivity {
    private EditText name;
    private EditText firstname;
    private EditText email;
    private EditText confirmEmail;
    private EditText password;
    private EditText confirmPassword;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_signup);

        name = findViewById(R.id.inputName);
        firstname = findViewById(R.id.inputPrenom);
        email = findViewById(R.id.inputEmail);
        confirmEmail = findViewById(R.id.inputConfEmail);
        password = findViewById(R.id.inputPassword);
        confirmPassword = findViewById(R.id.inputConfPassword);
        Button buttonCancel = findViewById(R.id.buttonCancel);
        Button buttonOk = findViewById(R.id.buttonOk);

        buttonCancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                finish();
            }
        });
        buttonOk.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                validateInput();
            }
        });
    }

    public void validateInput(){
        if(checkInputEmpty()){
            if(!InputController.passwordValidator(password.getText().toString())){
                Toast.makeText(this, "Password must contains 6 to 20 characters, one lowercase, one uppercase and one digit", Toast.LENGTH_LONG).show();
            }else if(InputController.validEmail(email.getText().toString())){
                User inputUser = new User(name.getText().toString(),firstname.getText().toString(),email.getText().toString(),password.getText().toString());
                new UserRegisterTask(this).execute(inputUser);
            }
        }
    }

    private boolean checkInputEmpty(){
        if(InputController.isEmptyEdit(name)){
            Toast.makeText(this, "You did not enter your name", Toast.LENGTH_SHORT).show();
            return false;
        } else if (!InputController.nameValidator(name.getText().toString())){
            Toast.makeText(this, "Name must be 4 to 30 character long", Toast.LENGTH_SHORT).show();
            return false;
        } else if(InputController.isEmptyEdit(firstname)){
            Toast.makeText(this, "You did not enter your firstname", Toast.LENGTH_SHORT).show();
            return false;
        } else if(InputController.isEmptyEdit(email)){
            Toast.makeText(this, "You did not enter your email", Toast.LENGTH_SHORT).show();
            return false;
        } else if(!InputController.validEmail(email.getText().toString())){
            Toast.makeText(this, "Your email is invalid", Toast.LENGTH_SHORT).show();
            return false;
        } else if(InputController.isEmptyEdit(confirmEmail)){
            Toast.makeText(this, "You did not confirm your email", Toast.LENGTH_SHORT).show();
            return false;
        } else if(InputController.isEmptyEdit(password)){
            Toast.makeText(this, "You did not enter your password", Toast.LENGTH_SHORT).show();
            return false;
        } else if(InputController.isEmptyEdit(confirmPassword)){
            Toast.makeText(this, "You did not confirm your password", Toast.LENGTH_SHORT).show();
            return false;
        }else {
            if (!(password.getText().toString().equals(confirmPassword.getText().toString()))) {
                Toast.makeText(this, "Password don't match confirmation password", Toast.LENGTH_SHORT).show();
                return false;
            } else if (!(email.getText().toString().equals(confirmEmail.getText().toString()))) {
                Toast.makeText(this, "Email don't match confirmation email", Toast.LENGTH_SHORT).show();
                return false;
            }else{
                return true;
            }
        }
    }

    private class UserRegisterTask extends AsyncTask<User,Void,JSONObject> {
        Context mContext;
        private UserRegisterTask(final Context context){mContext=context;}

        @Override
        protected void onPostExecute(JSONObject result){
            try{
                if(result!=null){
                    if(result.getInt("status") == 200){
                        System.out.println(result);
                        Intent accountIntent = new Intent(RegisterActivity.this, UserAccountActivity.class);
                        accountIntent.putExtra("userHash", result.getString("userHash"));
                        RegisterActivity.this.startActivity(accountIntent);
                        finish();
                    }else{
                        Toast.makeText(mContext, result.getString("response"), Toast.LENGTH_SHORT).show();
                    }
                }else{
                    Toast.makeText(mContext, "AN ERROR OCCURED", Toast.LENGTH_SHORT).show();
                }
            }catch (Exception e){
                e.printStackTrace();
            }
        }

        @Override
        protected JSONObject doInBackground(User... users) {
            try{
                String url = Config.USER_REGISTER;
                HttpCallHandler httpCallHandler = new HttpCallHandler();
                return new JSONObject(httpCallHandler.executeRegisterHttp(url,users[0]));
            }catch (Exception e){
                e.printStackTrace();
                return null;
            }
        }
    }
}
